==> immersiveoverlays-1.4.0%2B1.20.1-fabric-sources.jar: cc/cassian/immersiveoverlays/compat/SophisticatedBackpacksCompat.java <==
package cc.cassian.immersiveoverlays.compat;

import cc.cassian.immersiveoverlays.overlay.OverlayHelpers;

//? if neoforge {
/*import net.neoforged.neoforge.items.ItemStackHandler;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.BackpackWrapper;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.IBackpackWrapper;
*///?} else if fabric {
import net.fabricmc.fabric.api.transfer.v1.item.ItemVariant;
import net.fabricmc.fabric.api.transfer.v1.storage.base.SingleSlotStorage;
import net.minecraft.class_1799;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.BackpackItem;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.BackpackWrapper;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.IBackpackWrapper;
import net.p3pp3rf1y.sophisticatedcore.inventory.InventoryHandler;
import java.util.Optional;

public class SophisticatedBackpacksCompat {

    public static void checkBackpackContents(class_1799 stack) {
        //? if neoforge {
        /*Optional<IBackpackWrapper> backpackWrapper = BackpackWrapper.fromExistingData(stack);
        if (backpackWrapper.isPresent()) {
            ItemStackHandler inventory = backpackWrapper.get().getInventoryHandler();
            for (int i =0; i < inventory.getSlots(); i++) {
                OverlayHelpers.isImportantItemOrContainer(inventory.getStackInSlot(i));
            }
        }
    *///?}
    //? if >1.21 && fabric {
    /*Optional<IBackpackWrapper> backpackWrapper = BackpackWrapper.fromExistingData(stack);
    if (backpackWrapper.isPresent()) {
        InventoryHandler inventory = backpackWrapper.get().getInventoryHandler();
        for (SingleSlotStorage<ItemVariant> slot : inventory.getSlots()) {
            OverlayHelpers.isImportantItemOrContainer(slot.getResource().toStack());
        }
    }
    *///?} else if fabric {
    if (stack.method_7909() instanceof BackpackItem) {
        IBackpackWrapper backpackWrapper = new BackpackWrapper(stack);
        InventoryHandler inventory = backpackWrapper.getInventoryHandler();
        for (int i =0; i < inventory.getBaseSlotLimit(); i++) {
            OverlayHelpers.isImportantItemOrContainer(inventory.getStackInSlot(i));
        }
    }
    //?} else if forge {
        /*if (stack.getItem() instanceof BackpackItem) {
            IBackpackWrapper backpackWrapper = new BackpackWrapper(stack);
            ItemStackHandler inventory = backpackWrapper.getInventoryHandler();
            for (int i =0; i < inventory.getSlots(); i++) {
                OverlayHelpers.isImportantItemOrContainer(inventory.getStackInSlot(i));
            }
        }
        *///?}
    }
}

==> immersiveoverlays-1.4.4%2B1.21.1-fabric-sources.jar: cc/cassian/immersiveoverlays/compat/SophisticatedBackpacksCompat.java <==
package cc.cassian.immersiveoverlays.compat;

import cc.cassian.immersiveoverlays.overlay.OverlayHelpers;

//? if neoforge {
/*import net.neoforged.neoforge.items.ItemStackHandler;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.BackpackWrapper;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.IBackpackWrapper;
*///?} else if fabric {
import net.fabricmc.fabric.api.transfer.v1.item.ItemVariant;
import net.fabricmc.fabric.api.transfer.v1.storage.base.SingleSlotStorage;
import net.minecraft.class_1799;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.BackpackItem;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.BackpackWrapper;
import net.p3pp3rf1y.sophisticatedbackpacks.backpack.wrapper.IBackpackWrapper;
import net.p3pp3rf1y.sophisticatedcore.inventory.InventoryHandler;
import java.util.Optional;

public class SophisticatedBackpacksCompat {

    public static void checkBackpackContents(class_1799 stack) {
        //? if neoforge {
        /*Optional<IBackpackWrapper> backpackWrapper = BackpackWrapper.fromExistingData(stack);
        if (backpackWrapper.isPresent()) {
            ItemStackHandler inventory = backpackWrapper.get().getInventoryHandler();
            for (int i =0; i < inventory.getSlots(); i++) {
                OverlayHelpers.isImportantItemOrContainer(inventory.getStackInSlot(i));
            }
        }
    *///?}
    //? if >1.21 && fabric {
    Optional<IBackpackWrapper> backpackWrapper = BackpackWrapper.fromExistingData(stack);
    if (backpackWrapper.isPresent()) {
        InventoryHandler inventory = backpackWrapper.get().getInventoryHandler();
        for (SingleSlotStorage<ItemVariant> slot : inventory.getSlots()) {
            OverlayHelpers.isImportantItemOrContainer(slot.getResource().toStack());
        }
    }
    //?} else if fabric && >1.19 {
    /*if (stack.getItem() instanceof BackpackItem) {
        IBackpackWrapper backpackWrapper = new BackpackWrapper(stack);
        InventoryHandler inventory = backpackWrapper.getInventoryHandler();
        for (int i =0; i < inventory.getBaseSlotLimit(); i++) {
            OverlayHelpers.isImportantItemOrContainer(inventory.getStackInSlot(i));
        }
    }
    *///?} else if forge {
        /*if (stack.getItem() instanceof BackpackItem) {
            IBackpackWrapper backpackWrapper = new BackpackWrapper(stack);
            ItemStackHandler inventory = backpackWrapper.getInventoryHandler();
            for (int i =0; i < inventory.getSlots(); i++) {
                OverlayHelpers.isImportantItemOrContainer(inventory.getStackInSlot(i));
            }
        }
        *///?}
    }
}
